//
//	math.h
//

#ifndef __MATH_H__
#define __MATH_H__

class Math
{
public:
	static int choose (int n, int m);
	static int factorial (int n);
	static int stirling (int n, int k);	// ... of the first kind
};

#endif	// __MATH_H__
