//
//	aboutbox.h
//

#ifndef __ABOUTBOX_H__
#define __ABOUTBOX_H__

#include "wx/dialog.h"


class AboutBox : public wxDialog
{
private:
	//DECLARE_EVENT_TABLE()

public:
	AboutBox (wxWindow *parent);
};

#endif	// __ABOUTBOX_H__
