//
//	phrases.h: Automatically generated - do not edit!
//		(edit phrases.lang instead, and re-run init-phrases.sh)
//

static const char *phrases_raw =
"#	vim:set encoding=utf-8 fileencoding=utf-8 ts=8:\n"
"# GraphThing phrase translation file\n"
"\n"
"# Format:\n"
"#  * Each phrase is a quoted string (multiple quoted strings are\n"
"#	concatenated)\n"
"#  * If a quote-mark is desired in a phrase, backslash it; if you want\n"
"#	a backslash, use a double-backslash (\\)\n"
"#  * A phrase-block begins with the English phrase, an '=', a '{', a\n"
"#	series of translations, and a '}'. A block always finishes with ';'\n"
"#  * Each translation is a language name, an '=', and a phrase\n"
"\n"
"# Notes:\n"
"#  * Not all languages have to have an entry in a phrase-block;\n"
"#	if a translation is missing, it will default to English\n"
"#  * Please be very careful to preserve punctuation\n"
"#  * Be *extremely* careful to use the conversion specifiers correctly;\n"
"#	the order of specifiers MUST be identical in a phrase-block\n"
"\n"
"# Languages presently accepted:\n"
"#	Catalan (ca), Danish (dk), Dutch (nl), Esperanto (eo), English (en),\n"
"#	Finnish (fi), French (fr), German (de), Greek (el), Italian (it),\n"
"#	Norwegian (no), Polish (pl), Portuguese (pt), Romanian (ro),\n"
"#	Spanish (es), Swedish (sv), SwedishChef (sv_CK)\n"
"\n"
"#------------------------- Meta -------------------------#\n"
"\"Version\" = {\n"
"	Catalan = \"Versió\"\n"
"	ChineseSimp = \"版本\"\n"
"	French = \"Version\"\n"
"	German = \"Version\"\n"
"	Italian = \"Versione\"\n"
"	Romanian = \"Versiunea\"\n"
"	Spanish = \"Versión\"\n"
"	SwedishChef = \"Ferseeun\"\n"
"};\n"
"\n"
"# This one's a bit special - it should be the name of the language, as written\n"
"# in that language\n"
"\"English\" = {\n"
"	Catalan = \"Català\"\n"
"	ChineseSimp = \"简体中文\"\n"
"	French = \"Français\"\n"
"	German = \"Deutsch\"\n"
"	Italian = \"Italiano\"\n"
"	Romanian = \"Românã\"\n"
"	Spanish = \"Español\"\n"
"	SwedishChef = \"Svedeesh Cheff\"\n"
"};\n"
"\n"
"#------------------------- General -------------------------#\n"
"# (stuff in this section aren't actually strings that need\n"
"#  translation. They are mostly commonly used words)\n"
"\n"
"\"About\" = \"&About\" subst \"&\" / \"\";\n"
"\"All\" = {\n"
"	Catalan = \"Ambdós\"\n"
"	ChineseSimp = \"全部\"\n"
"	French = \"Tous\"\n"
"	German = \"Alle\"\n"
"	Italian = \"Tutto\"\n"
"	Romanian = \"Tot\"\n"
"	Spanish = \"Ambos\"\n"
"	SwedishChef = \"Ell\"\n"
"};\n"
"\"&Edges\" = {\n"
"	Catalan = \"&Arestes\"\n"
"	ChineseSimp = \"边(&E)\"\n"
"	French = \"&Sommets\"\n"
"	German = \"&Kanten\"\n"
"	Italian = \"&Archi\"\n"
"	Romanian = \"&Muchii\"\n"
"	Spanish = \"&Aristas\"\n"
"	SwedishChef = \"&Idges\"\n"
"};\n"
"\"&Vertices\" = {\n"
"	Catalan = \"&Vèrtexs\"\n"
"	ChineseSimp = \"顶点(&V)\"\n"
"	French = \"&Arêtes\"\n"
"	German = \"&Vertizen\"\n"
"	Italian = \"&Vertici\"\n"
"	Romanian = \"&Vârfuri\"\n"
"	Spanish = \"&Vértices\"\n"
"	SwedishChef = \"&Ferteeces\"\n"
"};\n"
"\n"
"#------------------------- Menus -------------------------#\n"
"### File\n"
"\"&File\" = {\n"
"	Catalan = \"&Fitxer\"\n"
"	ChineseSimp = \"文件(&F)\"\n"
"	French = \"&Fichier\"\n"
"	German = \"&Datei\"\n"
"	Italian = \"&File\"\n"
"	Romanian = \"&Fiºier\"\n"
"	Spanish = \"&Fichero\"\n"
"	SwedishChef = \"&Feele-a\"\n"
"};\n"
"\"&Load\tCtrl-O\" = \"&Load\" + \"\tCtrl-O\";\n"
"\"\tCtrl-O\" = literal;\n"
"\"&Load\" = {\n"
"	Catalan = \"&Obrir\"\n"
"	ChineseSimp = \"打开(&L)\"\n"
"	French = \"&Ouvrir\"\n"
"	German = \"&Öffnen\"\n"
"	Italian = \"&Carica\"\n"
"	Romanian = \"&Încãrcare\"\n"
"	Spanish = \"&Abrir\"\n"
"	SwedishChef = \"&Lued\"\n"
"};\n"
"\"&Save\tCtrl-S\" = \"&Save\" + \"\tCtrl-S\";\n"
"\"\tCtrl-S\" = literal;\n"
"\"&Save\" = {\n"
"	Catalan = \"&Desar\"\n"
"	ChineseSimp = \"保存(&S)\"\n"
"	French = \"&Sauver\"\n"
"	German = \"&Speichern\"\n"
"	Italian = \"&Salva\"\n"
"	Romanian = \"&Salvare\"\n"
"	Spanish = \"&Guardar\"\n"
"	SwedishChef = \"&Sefe-a\"\n"
"};\n"
"#\"&Print\tCtrl-P\" = \"&Print\" + \"\tCtrl-P\";\n"
"#\"\tCtrl-P\" = literal;\n"
"#\"&Print\" = {\n"
"#	Catalan = \"Im&primir\"\n"
"#	ChineseSimp = \"打印(&P)\"\n"
"#	French = \"Im&primer\"\n"
"#	German = \"&Drucken\"\n"
"#	Italian = \"Stam&pa\"\n"
"#	Romanian = \"&Tipãrire\"\n"
"#	Spanish = \"Im&primir\"\n"
"#	SwedishChef = \"&Preent\"\n"
"#};\n"
"\"E&xit\tCtrl-Q\" = \"E&xit\" + \"\tCtrl-Q\";\n"
"\"\tCtrl-Q\" = literal;\n"
"\"E&xit\" = {\n"
"	Catalan = \"&Sortir\"\n"
"	ChineseSimp = \"退出(&x)\"\n"
"	French = \"&Quitter\"\n"
"	German = \"B&eenden\"\n"
"	Italian = \"&Esci\"\n"
"	Romanian = \"I&eºire\"\n"
"	Spanish = \"&Salir\"\n"
"	SwedishChef = \"I&xeet\"\n"
"};\n"
"\n"
"### Edit\n"
"\"&Edit\" = {\n"
"	Catalan = \"&Editar\"\n"
"	ChineseSimp = \"编辑(&E)\"\n"
"	French = \"&Éditer\"\n"
"	German = \"&Editieren\"\n"
"	Italian = \"&Modifica\"\n"
"	Romanian = \"&Editare\"\n"
"	Spanish = \"&Editar\"\n"
"	SwedishChef = \"&Ideet\"\n"
"};\n"
"\"&Undo\tCtrl-Z\" = \"&Undo\" + \"\tCtrl-Z\";\n"
"\"\tCtrl-Z\" = literal;\n"
"\"&Undo\" = {\n"
"	Catalan = \"&Desfer\"\n"
"	ChineseSimp = \"撤销(&U)\"\n"
"	French = \"&Annuler\"\n"
"	German = \"&Rückgängig\"\n"
"	Italian = \"&Annulla\"\n"
"	Romanian = \"&Anuleazã\"\n"
"	Spanish = \"&Deshacer\"\n"
"	SwedishChef = \"&Undu\"\n"
"};\n"
"\"Select &All\tCtrl-A\" = \"Select &All\" + \"\tCtrl-A\";\n"
"\"\tCtrl-A\" = literal;\n"
"\"Select &All\" = {\n"
"	Catalan = \"Selecciona &Tot\"\n"
"	ChineseSimp = \"全选(&A)\"\n"
"	French = \"Tout &sélectionner\"\n"
"	German = \"&Alles auswählen\"\n"
"	Italian = \"Seleziona &Tutto\"\n"
"	Romanian = \"&Selecteazã tot\"\n"
"	Spanish = \"Selecciona &Todo\"\n"
"	SwedishChef = \"Select &Ell\"\n"
"};\n"
"\"Select &None\" = {\n"
"	Catalan = \"Selecciona &Cap\"\n"
"	ChineseSimp = \"取消选择(&N)\"\n"
"	French = \"Tout &désélectionner\"\n"
"	German = \"&Nichts auswählen\"\n"
"	Italian = \"&Nessuna Selezione\"\n"
"	Romanian = \"&Deselecteazã tot\"\n"
"	Spanish = \"Selecciona &Ninguno\"\n"
"	SwedishChef = \"Select &Noon\"\n"
"};\n"
"\"&Invert Selection\" = {\n"
"	Catalan = \"&Invertir selecció\"\n"
"	ChineseSimp = \"反向选择(&I)\"\n"
"	French = \"&Inverser la sélection\"\n"
"	German = \"Auswahl &Invertieren\"\n"
"	Italian = \"&Inverti Selezione\"\n"
"	Romanian = \"&Inverseazã selecþia\"\n"
"	Spanish = \"&Invertir selección\"\n"
"	SwedishChef = \"&Infert Selecshun\"\n"
"};\n"
"\"Invert Selection\" = \"&Invert Selection\" subst \"&\" / \"\";\n"
"\"Invert Selection (&Vertices)\" = \"Invert Selection\" + \" (\" + \"&Vertices\" + \")\";\n"
"\"Invert Selection (&Edges)\" = \"Invert Selection\" + \" (\" + \"&Edges\" + \")\";\n"
"\"&Invert Selection (All)\" = \"&Invert Selection\" + \" (\" + \"All\" + \")\";\n"
"\n"
"\n"
"### View\n"
"\"&View\" = {\n"
"	Catalan = \"&Veure\"\n"
"	ChineseSimp = \"视图(&V)\"\n"
"	French = \"&Vue\"\n"
"	German = \"&Ansicht\"\n"
"	Italian = \"&Vista\"\n"
"	Romanian = \"A&ratã\"\n"
"	Spanish = \"&Ver\"\n"
"	SwedishChef = \"F&eeoo\"\n"
"};\n"
"\"&Labels\" = {\n"
"	Catalan = \"&Etiquetes\"\n"
"	ChineseSimp = \"标签(&L)\"\n"
"	French = \"&Étiquettes\"\n"
"	German = \"&Bezeichnungen\"\n"
"	Italian = \"&Etichetta\"\n"
"	Romanian = \"&Etichetã\"\n"
"	Spanish = \"&Etiquetas\"\n"
"	SwedishChef = \"&Lebels\"\n"
"};\n"
"\"&Weights\" = {\n"
"	Catalan = \"&Pesos\"\n"
"	ChineseSimp = \"权值(&W)\"\n"
"	French = \"&Poids\"\n"
"	German = \"&Gewichte\"\n"
"	Italian = \"&Peso\"\n"
"	Romanian = \"&Cost\"\n"
"	Spanish = \"&Pesos\"\n"
"	SwedishChef = \"&Veeeghts\"\n"
"};\n"
"\"&Flows\" = {\n"
"	Catalan = \"&Fluxos\"\n"
"	ChineseSimp = \"流量(&F)\"\n"
"	French = \"&Flux\"\n"
"	Italian = \"&Flusso\"\n"
" 	Romanian = \"&Flux\"\n"
"	Spanish = \"&Flujos\"\n"
"	SwedishChef = \"&Floos\"\n"
"};\n"
"\n"
"### Graph\n"
"\"&Graph\" = {\n"
"	Catalan = \"&Graf\"\n"
"	ChineseSimp = \"图(&G)\"\n"
"	French = \"&Graphe\"\n"
"	German = \"&Graph\"\n"
"	Italian = \"&Grafo\"\n"
"	Romanian = \"&Graf\"\n"
"	Spanish = \"&Grafo\"\n"
"	SwedishChef = \"&Greph\"\n"
"};\n"
"\"&Clear\tCtrl-W\" = \"&Clear\" + \"\tCtrl-W\";\n"
"\"\tCtrl-W\" = literal;\n"
"\"&Clear\" = {\n"
"	Catalan = \"Es&borrar\"\n"
"	ChineseSimp = \"清除(&C)\"\n"
"	French = \"&Effacer\"\n"
"	German = \"&Löschen\"\n"
"	Italian = \"&Cancella\"\n"
"	Romanian = \"&ªterge\"\n"
"	Spanish = \"&Borrar\"\n"
"	SwedishChef = \"&Cleer\"\n"
"};\n"
"\"C&omplement\" = {\n"
"	Catalan = \"C&omplementari\"\n"
"	ChineseSimp = \"补图(&o)\"\n"
"	French = \"&Complémentaire\"\n"
"	German = \"&Komplement\"\n"
"	Italian = \"C&omplementario\"\n"
"	Romanian = \"C&omplement\"\n"
"	Spanish = \"C&omplementario\"\n"
"	SwedishChef = \"C&umplement\"\n"
"};\n"
"\"&Line Graph\" = {\n"
"	Catalan = \"Graf &línia\"\n"
"	ChineseSimp = \"边图(&L)\"\n"
"	French = \"Graphe &Linéaire\"\n"
"	German = \"&Line Graph\"\n"
"	Italian = \"Grafo a &Linee\"\n"
"	Romanian = \"&Line Graph\"\n"
"	Spanish = \"Grafo &línea\"\n"
"	SwedishChef = \"&Leene-a Greph\"\n"
"};\n"
"\"S&ubgraph\" = {\n"
"	Catalan = \"S&ubgraf\"\n"
"	ChineseSimp = \"诱导子图(&u)\"\n"
"	French = \"So&us-graphe\"\n"
"	German = \"S&ubgraph\"\n"
"	Italian = \"So&ttografo\"\n"
"	Romanian = \"S&ubgraf\"\n"
"	Spanish = \"S&ubgrafo\"\n"
"	SwedishChef = \"S&oobgreph\"\n"
"};\n"
"###### Find\n"
"\"&Find\" = {\n"
"	Catalan = \"&Cercar\"\n"
"	ChineseSimp = \"寻找(&F)\"\n"
"	French = \"&Chercher\"\n"
"	German = \"&Suchen\"\n"
"	Italian = \"C&erca\"\n"
"	Romanian = \"&Cãutare\"\n"
"	Spanish = \"&Buscar\"\n"
"	SwedishChef = \"&Feend\"\n"
"};\n"
"\"&Shortest Path\" = {\n"
"	Catalan = \"&Camí més curt\"\n"
"	ChineseSimp = \"最短路(&S)\"\n"
"	French = \"&Plus court chemin\"\n"
"	German = \"&Kürzester Weg\"\n"
"	Italian = \"&Cammino minimo\"\n"
"	Romanian = \"Cel mai &scurt drum\"\n"
"	Spanish = \"&Camino más corto\"\n"
"	SwedishChef = \"&Shurtest Pet\"\n"
"};\n"
"\"&Breadth-First Search\" = {\n"
"	Catalan = \"Cerca en &amplada\"\n"
"	ChineseSimp = \"宽度优先搜索(&B)\"\n"
"	French = \"Recherche en &largeur\"\n"
"	German = \"&Breitensuche\"\n"
"	Italian = \"Ricerca in &ampiezza\"\n"
"	Romanian = \"Cãutare în &lãtime\"\n"
"	Spanish = \"Búsqueda en &anchura\"\n"
"	SwedishChef = \"&Breedt-Furst Seerch\"\n"
"};\n"
"\"&Depth-First Search\" = {\n"
"	Catalan = \"Cerca en &profunditat\"\n"
"	ChineseSimp = \"深度优先搜索(&D)\"\n"
"	French = \"Recherche en p&rofondeur\"\n"
"	German = \"&Tiefensuche\"\n"
"	Italian = \"Ricerca in &Profondità\"\n"
"	Romanian = \"Cãutare în &adâncime\"\n"
"	Spanish = \"Búsqueda en &profundidad\"\n"
"	SwedishChef = \"&Dept-Furst Seerch\"\n"
"};\n"
"\"&Minimum Spanning Tree\" = {\n"
"	Catalan = \"&Arbre d'expansió mínim\"\n"
"	ChineseSimp = \"最小生成树(&M)\"\n"
"	French = \"Enjambement d'arbre &minimum\"\n"
"	German = \"&Minimaler aufspannender Baum\"\n"
"	Italian = \"Albero dei Cammini &Minimo\"\n"
"	Romanian = \"Arbore &minim de acoperire\"\n"
"	Spanish = \"&Ãrbol de expansión mínimo\"\n"
"	SwedishChef = \"&Meenimoom Spunneeng Tree-a\"\n"
"};\n"
"\"Maximum &Flow\" = {\n"
"	Catalan = \"&Flux màxim\"\n"
"	ChineseSimp = \"最大流(&F)\"\n"
"	French = \"&Flux maximal\"\n"
"	Italian = \"Massimo &Flusso\"\n"
" 	Romanian = \"&Flux maxim\"\n"
"	Spanish = \"&Flujo máximo\"\n"
"	SwedishChef = \"Mexeemoom &Floo\"\n"
"};\n"
"###### Properties\n"
"\"&Properties\" = {\n"
"	Catalan = \"&Propietats\"\n"
"	ChineseSimp = \"性质(&P)\"\n"
"	French = \"&Propriétés\"\n"
"	German = \"&Eigenschaften\"\n"
"	Italian = \"&Proprietà\"\n"
"	Romanian = \"&Proprietãþi\"\n"
"	Spanish = \"&Propiedades\"\n"
"	SwedishChef = \"&Pruperteees\"\n"
"};\n"
"\"&Connectivity\" = {\n"
"	Catalan = \"&Connexió\"\n"
"	ChineseSimp = \"连通性(&C)\"\n"
"	French = \"&Connectivité\"\n"
"	German = \"&Zusammenhängender Graph\"\n"
"	Italian = \"&Connetività\"\n"
"	Romanian = \"&Conectivitate\"\n"
"	Spanish = \"&Conexión\"\n"
"	SwedishChef = \"&Cunnecteefity\"\n"
"};\n"
"\"&Eulericity\" = {\n"
"	Catalan = \"&Eulericitat\"\n"
"	ChineseSimp = \"欧拉图(&E)\"\n"
"	French = \"&Eulericité\"\n"
"	German = \"&Eulerschergraph\"\n"
"	Italian = \"&Eulericità\"\n"
"	Romanian = \"&Eulericitate\"\n"
"	Spanish = \"&Eulericidad\"\n"
"	SwedishChef = \"&Ioolereecity\"\n"
"};\n"
"\"&Hamiltonicity\" = {\n"
"	Catalan = \"&Hamiltonicitat\"\n"
"	ChineseSimp = \"哈密顿图(&H)\"\n"
"	French = \"&Hamiltonicité\"\n"
"	German = \"&Hamiltongraph\"\n"
"	Italian = \"&Hamiltonianità\"\n"
"	Romanian = \"&Hamiltonitate\"\n"
"	Spanish = \"&Hamiltonicidad\"\n"
"	SwedishChef = \"&Hemeeltunicity\"\n"
"};\n"
"\"&Planarity\" = {\n"
"	Catalan = \"&Planaritat\"\n"
"	ChineseSimp = \"可平面性(&P)\"\n"
"	French = \"&Planarité\"\n"
"	German = \"&Planarität\"\n"
"	Italian = \"&Planarità\"\n"
"	Romanian = \"&Planaritate\"\n"
"	Spanish = \"&Planaridad\"\n"
"	SwedishChef = \"&Plunereety\"\n"
"};\n"
"###### Statistics\n"
"\"&Statistics\" = {\n"
"	Catalan = \"E&stadístiques\"\n"
"	ChineseSimp = \"统计(&S)\"\n"
"	French = \"&Statistiques\"\n"
"	German = \"S&tatistiken\"\n"
"	Italian = \"&Statistiche\"\n"
"	Romanian = \"&Statistici\"\n"
"	Spanish = \"E&stadísticas\"\n"
"	SwedishChef = \"&Steteestics\"\n"
"};\n"
"\"&Adjacency Matrix\" = {\n"
"	Catalan = \"Matriu d'&adjacència\"\n"
"	ChineseSimp = \"邻接矩阵(&A)\"\n"
"	French = \"Matrice &adjacente\"\n"
"	German = \"&Adjazenzmatrix\"\n"
"	Italian = \"Matrice d'&adiacenza\"\n"
"	Romanian = \"Matrice de &adiacenþã\"\n"
"	Spanish = \"Matriz de &adyacencia\"\n"
"	SwedishChef = \"&Edjecency Metreex\"\n"
"};\n"
"\"&Degree Sequence\" = {\n"
"	Catalan = \"Successió de &graus\"\n"
"	ChineseSimp = \"度序列(&D)\"\n"
"	French = \"Séquence de &degrés\"\n"
"	German = \"&Grad Sequenz\"\n"
"	Italian = \"Successione del &grado\"\n"
"	Romanian = \"&Succesiune de grade\"\n"
"	Spanish = \"Sucesión de &grados\"\n"
"	SwedishChef = \"&Degree-a Seqooence-a\"\n"
"};\n"
"\"D&iameter\" = {\n"
"	Catalan = \"&Diàmetre\"\n"
"	ChineseSimp = \"直径(&i)\"\n"
"	French = \"&Diamètre\"\n"
"	German = \"&Durchmesser\"\n"
"	Italian = \"&Diametro\"\n"
"	Romanian = \"&Diametru\"\n"
"	Spanish = \"&Diámetro\"\n"
"	SwedishChef = \"Deee&meter\"\n"
"};\n"
"\"&Girth\" = {\n"
"	Catalan = \"G&irth\"\n"
"	ChineseSimp = \"围长(&G)\"\n"
"	French = \"&Périmètre\"\n"
"	German = \"&Umfang\"\n"
"	Italian = \"G&irth\"\n"
"	Romanian = \"&Girth\"\n"
"	Spanish = \"G&irth\"\n"
"	SwedishChef = \"&Gurt\"\n"
"};\n"
"\"&Radius\" = {\n"
"	Catalan = \"&Radi\"\n"
"	ChineseSimp = \"半径(&R)\"\n"
"	French = \"&Rayon\"\n"
"	German = \"&Radius\"\n"
"	Italian = \"&Raggio\"\n"
"	Romanian = \"&Razã\"\n"
"	Spanish = \"&Radio\"\n"
"	SwedishChef = \"&Redeeoos\"\n"
"};\n"
"\"&Chromatic Number\" = {\n"
"	Catalan = \"Número &Cromàtic\"\n"
"	ChineseSimp = \"色数(&C)\"\n"
"	French = \"Nombre &chromatique\"\n"
"	German = \"&Chormatische Zahl\"\n"
"	Italian = \"Numero &Cromatico\"\n"
"	Romanian = \"&Numãr cromatic\"\n"
"	Spanish = \"Número &Cromático\"\n"
"	SwedishChef = \"&Chrumeteec Noomber\"\n"
"};\n"
"\"C&hromatic Index\" = {\n"
"	Catalan = \"Índex cro&màtic\"\n"
"	ChineseSimp = \"色指数(&h)\"\n"
"	French = \"Index c&hromatique\"\n"
"	German = \"C&hromatischer Index\"\n"
"	Italian = \"I&ndice Cromatico\"\n"
"	Romanian = \"&Index Cromatic\"\n"
"	Spanish = \"Índice cro&mático\"\n"
"	SwedishChef = \"C&hrumeteec Index\"\n"
"};\n"
"\"Chromatic &Polynomial\" = {\n"
"	Catalan = \"&Polinomi Cromàtic\"\n"
"	ChineseSimp = \"色多项式(&P)\"\n"
"	French = \"&Polynome chromatique\"\n"
"	German = \"Chromatisches &Polynom\"\n"
"	Italian = \"&Polinomio Cromatico\"\n"
"	Romanian = \"&Polinom Cromatic\"\n"
"	Spanish = \"&Polinomio Cromático\"\n"
"	SwedishChef = \"Chrumeteec &Pulynumeeel\"\n"
"};\n"
"\n"
"### Prefab\n"
"\"&Prefab\" = {\n"
"	Catalan = \"&Preestablert\"\n"
"	ChineseSimp = \"预置图(&P)\"\n"
"	French = \"&Préconçus\"\n"
"	German = \"&Vorgefertigt\"\n"
"	Italian = \"&Predefinito\"\n"
"	Romanian = \"&Prestabilite\"\n"
"	Spanish = \"&Preestablecido\"\n"
"	SwedishChef = \"&Preffeb\"\n"
"};\n"
"\"Complete (&Kn)\" = {\n"
"	Catalan = \"Complet (&Kn)\"\n"
"	ChineseSimp = \"完全图(Kn)(&K)\"\n"
"	French = \"Complet (&Kn)\"\n"
"	German = \"Vollständig (&Kn)\"\n"
"	Italian = \"Completo (&Kn)\"\n"
"	Romanian = \"Complet (&Kn)\"\n"
"	Spanish = \"Completo (&Kn)\"\n"
"	SwedishChef = \"Cumplete-a (&Kn)\"\n"
"};\n"
"\"Complete &Bipartite (Kn,m)\" = {\n"
"	Catalan = \"&Bipartit complet (Kn,m)\"\n"
"	ChineseSimp = \"完全二分图(Kn,m)(&B)\"\n"
"	French = \"Complet Bipartite (&Kn,m)\"\n"
"	German = \"Vollständig &zweigeteilt (Kn,m)\"\n"
"	Italian = \"&Bipartito Completo (Kn,m)\"\n"
"	Romanian = \"Complet &bipartit (Kn,m)\"\n"
"	Spanish = \"&Bipartido completo (Kn,m)\"\n"
"	SwedishChef = \"Cumplete-a &Beepertite-a (Kn,m)\"\n"
"};\n"
"\"Cycle (&Cn)\" = {\n"
"	Catalan = \"Cicle (&Cn)\"\n"
"	ChineseSimp = \"环(Cn)(&C)\"\n"
"	French = \"Cycle (&Cn)\"\n"
"	German = \"Kreis (&Cn)\"\n"
"	Italian = \"Ciclo (&Cn)\"\n"
"	Romanian = \"Ciclu (&Cn)\"\n"
"	Spanish = \"Ciclo (&Cn)\"\n"
"	SwedishChef = \"Cycle-a (&Cn)\"\n"
"};\n"
"\"Gear (&Gn)\" = {\n"
"	Catalan = \"Graf pinyó (&Gn)\"\n"
"	ChineseSimp = \"齿轮图(Gn)(&G)\"\n"
"	French = \"Volant (&Gn)\"\n"
"	German = \"Verzahnter (&Gn)\"\n"
"	Italian = \"Gear (&Gn)\"\n"
"	Romanian = \"Gear (&Gn)\"\n"
"	Spanish = \"Grafo piñón (&Gn)\"\n"
"	SwedishChef = \"Geer (&Gn)\"\n"
"};\n"
"\"Hanoi (&Hn)\" = {\n"
"	Catalan = \"Hanoi (&Hn)\"\n"
"	ChineseSimp = \"Hanoi(Hn)(&H)\"\n"
"##### [fixme]\n"
"	French = \"Hanoi (&Hn)\"\n"
"	German = \"Hanoi (&Hn)\"\n"
"	Italian = \"Hanoi (&Hn)\"\n"
"	Romanian = \"Hanoi (&Hn)\"\n"
"	Spanish = \"Hanoi (&Hn)\"\n"
"	SwedishChef = \"Hunuee (&Hn)\"\n"
"};\n"
"\"Ladder (&Ln)\" = {\n"
"	Catalan = \"Escala (&Ln)\"\n"
"	ChineseSimp = \"Ladder (&Ln)\"\n"
"##### [fixme]\n"
"	French = \"Échelle (&Ln)\"\n"
"	German = \"Leiter (&Ln)\"\n"
"	Italian = \"Ladder (&Ln)\"\n"
"	Romanian = \"Scarã (&Ln)\"\n"
"	Spanish = \"Escalera (&Ln)\"\n"
"	SwedishChef = \"Ledder (&Ln)\"\n"
"};\n"
"\"Lattice (Ln,m)\" = {\n"
"	Catalan = \"Malla (Ln,m)\"\n"
"	ChineseSimp = \"Lattice (Ln,m)\"\n"
"##### [fixme]\n"
"	French = \"Maillage (Ln,m)\"\n"
"	German = \"Gitter (Ln,m)\"\n"
"	Italian = \"Lattice (Ln,m)\"\n"
"	Romanian = \"Lattice (Ln,m)\"\n"
"	Spanish = \"Malla (Ln,m)\"\n"
"	SwedishChef = \"Letteece-a (Ln,m)\"\n"
"};\n"
"\"Null (&Nn)\" = {\n"
"	Catalan = \"Nul (&Nn)\"\n"
"	ChineseSimp = \"空图(Nn)(&N)\"\n"
"	French = \"Nul (&Nn)\"\n"
"	German = \"Null (&Nn)\"\n"
"	Italian = \"Nullo (&Nn)\"\n"
"	Romanian = \"Nul (&Nn)\"\n"
"	Spanish = \"Nulo (&Nn)\"\n"
"	SwedishChef = \"Nooll (&Nn)\"\n"
"};\n"
"\"Star (&Sn)\" = {\n"
"	Catalan = \"Estel (&Sn)\"\n"
"	ChineseSimp = \"星(Sn)(&S)\"\n"
"	French = \"Étoile (&Sn)\"\n"
"	German = \"Stern (&Sn)\"\n"
"	Italian = \"Stella (&Sn)\"\n"
"	Romanian = \"Stea (&Sn)\"\n"
"	Spanish = \"Estrella (&Sn)\"\n"
"	SwedishChef = \"Ster (&Sn)\"\n"
"};\n"
"\"Tree (&Tn)\" = {\n"
"	Catalan = \"Arbre (&Tn)\"\n"
"	ChineseSimp = \"树(Tn)(&T)\"\n"
"	French = \"Arbre (&Tn)\"\n"
"	German = \"Baum (&Tn)\"\n"
"	Italian = \"Albero (&Tn)\"\n"
"	Romanian = \"Arbore (&Tn)\"\n"
"	Spanish = \"Ãrbol (&Tn)\"\n"
"	SwedishChef = \"Tree-a (&Tn)\"\n"
"};\n"
"\"Wheel (&Wn)\" = {\n"
"	Catalan = \"Roda (&Wn)\"\n"
"	ChineseSimp = \"轮状图(&Wn)(&W)\"\n"
"	French = \"Roue (&Wn)\"\n"
"	German = \"Rad (&Wn)\"\n"
"	Italian = \"Foresta (&Wn)\"\n"
"	Romanian = \"Roatã (&Wn)\"\n"
"	Spanish = \"Rueda (&Wn)\"\n"
"	SwedishChef = \"Vheel (&Wn)\"\n"
"};\n"
"\"Petersen\" = {\n"
"	Catalan = \"Petersen\"\n"
"	ChineseSimp = \"Petersen图\"\n"
"	French = \"Petersen\"\n"
"	German = \"Petersen\"\n"
"	Italian = \"Petersen\"\n"
"	Romanian = \"Petersen\"\n"
"	Spanish = \"Petersen\"\n"
"	SwedishChef = \"Petersee\"\n"
"};\n"
"###### Platonic\n"
"\"&Platonic\" = {\n"
"	Catalan = \"&Platònic\"\n"
"	ChineseSimp = \"柏拉图体(&P)\"\n"
"	French = \"&Platonique\"\n"
"	German = \"&Platonisch\"\n"
"	Italian = \"&Platonico\"\n"
"	Romanian = \"&Platonic\"\n"
"	Spanish = \"&Platónico\"\n"
"	SwedishChef = \"&Pletuneec\"\n"
"};\n"
"\"&Tetrahedral\" = {\n"
"	Catalan = \"&Tetraedre\"\n"
"	ChineseSimp = \"四面体(&T)\"\n"
"	French = \"&Tétraédral\"\n"
"	German = \"&Tetradrisch\"\n"
"	Italian = \"&Tetraedre\"\n"
"	Romanian = \"&Tetraedru\"\n"
"	Spanish = \"&Tetraedro\"\n"
"	SwedishChef = \"&Tetrehedrel\"\n"
"};\n"
"\"&Cubical\" = {\n"
"	Catalan = \"&Cub\"\n"
"	ChineseSimp = \"立方体(&C)\"\n"
"	French = \"&Cubique\"\n"
"	German = \"&Kubisch\"\n"
"	Italian = \"&Cubo\"\n"
"	Romanian = \"&Cub\"\n"
"	Spanish = \"&Cubo\"\n"
"	SwedishChef = \"&Coobeecel\"\n"
"};\n"
"\"&Octahedral\" = {\n"
"	Catalan = \"&Octoedre\"\n"
"	ChineseSimp = \"八面体(&O)\"\n"
"	French = \"&Octaédral\"\n"
"	German = \"&Oktaedrisch\"\n"
"	Italian = \"&Ottoedro\"\n"
"	Romanian = \"&Octaedru\"\n"
"	Spanish = \"&Octoedro\"\n"
"	SwedishChef = \"&Ooctehedrel\"\n"
"};\n"
"\"&Dodecahedral\" = {\n"
"	Catalan = \"&Dodecaedre\"\n"
"	ChineseSimp = \"十二面体(&D)\"\n"
"	French = \"&Dodécaédral\"\n"
"	German = \"&Dodekaedrisch\"\n"
"	Italian = \"&Dodecaedro\"\n"
"	Romanian = \"&Dodecaedru\"\n"
"	Spanish = \"&Dodecaedro\"\n"
"	SwedishChef = \"&Dudecehedrel\"\n"
"};\n"
"\"&Icosahedral\" = {\n"
"	Catalan = \"&Icosaedre\"\n"
"	ChineseSimp = \"二十面体(&I)\"\n"
"	French = \"&Icosaédral\"\n"
"	German = \"&Ikosaedrisch\"\n"
"	Italian = \"&Icosaedro\"\n"
"	Romanian = \"&Icosaedru\"\n"
"	Spanish = \"&Icosaedro\"\n"
"	SwedishChef = \"&Icusehedrel\"\n"
"};\n"
"\n"
"### Help\n"
"\"&Help\" = {\n"
"	Catalan = \"&Ajuda\"\n"
"	ChineseSimp = \"帮助(&H)\"\n"
"	French = \"&Aide\"\n"
"	German = \"&Hilfe\"\n"
"	Italian = \"&Aiuto\"\n"
"	Romanian = \"&Ajutor\"\n"
"	Spanish = \"&Ayuda\"\n"
"	SwedishChef = \"&Help\"\n"
"};\n"
"\"&About\tF1\" = \"&About\" + \"\tF1\";\n"
"\"\tF1\" = literal;\n"
"\"&About\" = {\n"
"	Catalan = \"&Sobre\"\n"
"	ChineseSimp = \"关于(&A)\"\n"
"	French = \"&À propos\"\n"
"	German = \"&Über\"\n"
"	Italian = \"&Informazioni\"\n"
"	Romanian = \"&Despre\"\n"
"	Spanish = \"&Sobre\"\n"
"	SwedishChef = \"&Ebuoot\"\n"
"};\n"
"\n"
"\n"
"### Popup menus\n"
"\"&Add Edge\" = {\n"
"	Catalan = \"&Afegir Aresta\"\n"
"	ChineseSimp = \"添加边(&A)\"\n"
"	French = \"&Ajouter une arête\"\n"
"	German = \"Kante &Hinzufügen\"\n"
"	Italian = \"&Aggiungi Arco\"\n"
"	Romanian = \"&Adaugã Muchie\"\n"
"	Spanish = \"&Añadir Arista\"\n"
"	SwedishChef = \"&Edd Idge-a\"\n"
"};\n"
"\"&Remove Edge\" = {\n"
"	Catalan = \"&Eliminar Aresta\"\n"
"	ChineseSimp = \"删除边(&R)\"\n"
"	French = \"&Supprimer une arête\"\n"
"	German = \"Kante &Entfernen\"\n"
"	Italian = \"&Elimina Arco\"\n"
"	Romanian = \"&ªterge Muchie\"\n"
"	Spanish = \"&Eliminar Arista\"\n"
"	SwedishChef = \"&Remufe-a Idge-a\"\n"
"};\n"
"\n"
"#------------------------- Dialogs -------------------------#\n"
"\n"
"\"About...\" = \"About\" + \"...\";\n"
"\n"
"# XXX: Are there better translations than these?\n"
"\"OK\" = {\n"
"	Catalan = \"OK\"\n"
"	ChineseSimp = \"确定\"\n"
"	French = \"OK\"\n"
"	German = \"OK\"\n"
"	Italian = \"OK\"\n"
"	Romanian = \"OK\"\n"
"	Spanish = \"OK\"\n"
"	SwedishChef = \"Ookey\"\n"
"};\n"
"\"Cancel\" = {\n"
"	Catalan = \"Cancel·lar\"\n"
"	ChineseSimp = \"取消\"\n"
"	French = \"Annuler\"\n"
"	German = \"Abbrechen\"\n"
"	Italian = \"Cancella\"\n"
"	Romanian = \"Renunþã\"\n"
"	Spanish = \"Cancelar\"\n"
"	SwedishChef = \"Cuncel\"\n"
"};\n"
"\n"
"\"Loading failed\" = {\n"
"	Catalan = \"Error en càrrega\"\n"
"	ChineseSimp = \"载入失败\"\n"
"	French = \"Chargement échoué\"\n"
"	German = \"Laden fehlgeschlagen\"\n"
"	Italian = \"Caricamento fallito\"\n"
"	Romanian = \"Încãrcarea a eºuat\"\n"
"	Spanish = \"Error en carga\"\n"
"	SwedishChef = \"Luedeeng feeeled\"\n"
"};\n"
"\n"
"\"This program is free software; you can redistribute\n\"\n"
"\"it and/or modify it under the terms of the GNU\n\"\n"
"\"General Public License, version 2, as published by\n\"\n"
"\"the Free Software Foundation.\n\n\"\n"
"\"This program is distributed in the hope that it will\n\"\n"
"\"be useful, but WITHOUT ANY WARRANTY; without even\n\"\n"
"\"the implied warranty of MERCHANTABILITY or FITNESS\n\"\n"
"\"FOR A PARTICULAR PURPOSE. See the GNU General\n\"\n"
"\"Public License for more details.\" = {\n"
"	Catalan =\n"
"		\"Traduït al català per\n\"\n"
"		\"Josep M. Lopez <josep.m.lopez@urv.cat>\"\n"
"		\"\n\n\"\n"
"		\"Aquest programa és Software Lliure; podeu\n\"\n"
"		\"redistribuir-lo i/o modificar-lo sota els termes\n\"\n"
"		\"de la \\\"GNU General Public License\\\" com la\n\"\n"
"		\"publica la \\\"FSF Free Software Foundation\\\".\n\n\"\n"
"		\"Aquest programa es distribueix esperant que\n\"\n"
"		\"us serà útil, pero SENSE CAP MENA DE GARANTIA;\n\"\n"
"		\"ni tan sols la garantía implícita pel MERCADEIG\n\"\n"
"		\"o EXERCICI D'ALGÃN PROPÃSIT en particular.\n\"\n"
"		\"Vegeu la \\\"GNU General Public License\\\" per més detalls.\"\n"
"	ChineseSimp =\n"
"		\"本程序为自由软件；您可依据自由软件基金会所发表的GNU通用公共\n\"\n"
"		\"授权条款规定，就本程序再次发布无论是否有修改。\n\n\"\n"
"		\"本程序是基于使用目的而加以发布，然而不负任何担保责任；亦无对\n\"\n"
"		\"适售性或特定目的适用性所为的默示性担保。详情请参照GNU通用公共授权。\"\n"
"	French =\n"
"		\"Traduit en français par\n\"\n"
"		\"Cyril Brulebois <cyril.brulebois@enst-bretagne.fr>\n\"\n"
"		\"\n\n\"\n"
"\n"
"		\"Ce programme est un logiciel libre ; vous pouvez\n\"\n"
"		\"le redistribuer et/ou le modifier au titre des\n\"\n"
"		\"clauses de la Licence Publique Générale GNU, telle\n\"\n"
"		\"que publiée par la Free Software Foundation ; soit\n\"\n"
"		\"la version 2 de la Licence. Ce programme est distribué\n\"\n"
"		\"dans l'espoir qu'il sera utile, mais SANS AUCUNE GARANTIE ;\n\"\n"
"		\"sans même une garantie implicite de COMMERCIABILITE ou\n\"\n"
"		\"DE CONFORMITE A UNE UTILISATION PARTICULIERE. Voir la\n\"\n"
"		\"Licence Publique Générale GNU pour plus de détails.\"\n"
"	German =\n"
"		\"Deutsche Übersetzung von\n\"\n"
"		\"Tilman Linneweh <arved@arved.at>\"\n"
"		\"\n\"\n"
"		\"Die Deutsche Übersetzung ist noch nicht perfekt. Bitte\n\"\n"
"		\"sendet Verbesserungsvorschläge an mich, Tilman Linneweh.\n\"\n"
"		\"\n\n\"\n"
"		\"Dieses Programm ist freie Software. Sie können es\n\"\n"
"		\"unter den Bedingungen der GNU General Public License,\n\"\n"
"		\"wie von der Free Software Foundation veröffentlicht,\n\"\n"
"		\"weitergeben und/oder modifizieren, entweder gemäß\n\"\n"
"		\"Version 2 der Lizenz.\n\n\"\n"
"		\"Die Veröffentlichung dieses Programms erfolgt in der\n\"\n"
"		\"Hoffnung, daß es Ihnen von Nutzen sein wird, aber\n\"\n"
"		\"OHNE IRGENDEINE GARANTIE, sogar ohne die implizite\n\"\n"
"		\"Garantie der MARKTREIFE oder der VERWENDBARKEIT\n\"\n"
"		\"FÜR EINEN BESTIMMTEN ZWECK. Details finden Sie in\n\"\n"
"		\"der GNU General Public License.\"\n"
"	Italian =\n"
"		\"Semi tradotto in Italiano da\n\"\n"
"		\"Matteo Boccafoli <boccafoli@gmail.com>\"\n"
"		\"\n\n\"\n"
"		\"Questo programma è software libero; è lecito ridistribuirlo\n\"\n"
"		\"e/o modificarlo secondo i termini della Licenza Pubblica\n\"\n"
"		\"Generica GNU come pubblicata dalla Free Software Foundation;\n\"\n"
"		\"o la versione 2 della licenza. Questo programma è\n\"\n"
"		\"distribuito nella speranza che sia utile, ma SENZA ALCUNA\n\"\n"
"		\"GARANZIA; senza neppure la garanzia implicita di\n\"\n"
"		\"COMMERCIABILITA o di APPLICABILITA PER UN PARTICOLARE\n\"\n"
"		\"SCOPO. Si veda la Licenza Pubblica Generica GNU per avere\n\"\n"
"		\"maggiori dettagli.\"\n"
"	Romanian = \n"
"		\"Traducerea în limba românã de\n\"\n"
"		\"Ion Savin <comp_@gmx.net>\n\n\"\n"
"		\"Acest program este liber; îl puteþi redistribui ºi/sau modifica în\n\"\n"
"		\"conformitate cu termenii Licenþei Publice Generale GNU aºa cum\n\"\n"
"		\"este publicatã de Free Software Foundation, versiunea 2 a Licenþei.\n\n\"\n"
"		\"Acest program este distribuit cu speranþa de a fi util, dar FÃRÃ\n\"\n"
"		\"NICI O GARANÞIE, fãrã garanþie implicitã de vandabilitate ºi\n\"\n"
"		\"conformitate unui anumit scop. Citiþi Licenþa Publicã Generalã GNU\n\"\n"
"		\"pentru detalii.\"\n"
"	Spanish =\n"
"		\"Traducido al español por\n\"\n"
"		\"Josep M. Lopez <josep.m.lopez@urv.cat>\"\n"
"		\"\n\n\"\n"
"		\"Este programa es Software Libre; usted puede\n\"\n"
"		\"redistribuirlo y/o modificarlo bajo los términos\n\"\n"
"		\"de la \\\"GNU General Public License\\\" como lo\n\"\n"
"		\"publica la \\\"FSF Free Software Foundation\\\".\n\n\"\n"
"		\"Este programa es distribuido con la esperanza\n\"\n"
"		\"de que le será útil, pero SIN NINGUNA GARANTIA;\n\"\n"
"		\"incluso sin la garantía implícita por el MERCADEO\n\"\n"
"		\"o EJERCICIO DE ALGUN PROPOSITO en particular.\n\"\n"
"		\"Vea la \\\"GNU General Public License\\\" para más detalles.\"\n"
"	SwedishChef =\n"
"		\"Svedeesh Cheff Trunsleshun by\n\"\n"
"		\"Defeed Symunds <dsymonds@gmail.com>\n\"\n"
"		\"(thunks tu \\\"Encheferizer\\\" by Juhn Hegermun:\n\"\n"
"		\"http://www.almac.co.uk/chef/chef/chef.html)\"\n"
"		\"\n\n\"\n"
"		\"Thees prugrem is free-a sufftvere-a; yuoo cun\n\"\n"
"		\"redeestriboote-a it und/oor mudeeffy it under zee\n\"\n"
"		\"terms ooff zee GNOO Generel Poobleec Leecense-a,\n\"\n"
"		\"ferseeun 2, es poobleeshed by zee Free-a Sufftvere-a\n\"\n"
"		\"Fuoondeshun.\n\n\"\n"
"		\"Thees prugrem is deestribooted in zee hupe-a thet\n\"\n"
"		\"it veell be-a useffool, boot VITHOOOT ENY VERRENTY;\n\"\n"
"		\"veethuoot ifee zee impleeed verrunty ooff\n\"\n"
"		\"MERCHENTEBILITY oor FITNESS FOR A PERTICOOLER\n\"\n"
"		\"POORPOSE. See-a zee GNOO Generel Poobleec Leecense-a\n\"\n"
"		\"fur mure-a deteeels.\"\n"
"};\n"
"\n"
"\"Edge Properties\" = {\n"
"	Catalan = \"Propietats de l'aresta\"\n"
"	ChineseSimp = \"边属性\"\n"
"	French = \"Propriétés de l'arête\"\n"
"	German = \"Kanten Eigenschaften\"\n"
"	Italian = \"Proprietà dell'arco\"\n"
"	Romanian = \"Proprietãþi Muchie\"\n"
"	Spanish = \"Propiedades de la arista\"\n"
"	SwedishChef = \"Idge-a Pruperteees\"\n"
"};\n"
"\"Edge weight:\" = {\n"
"	Catalan = \"Pes de l'aresta:\"\n"
"	ChineseSimp = \"边权值：\"\n"
"	French = \"Poids de l'arête :\"\n"
"	German = \"Kantengewicht:\"\n"
"	Italian = \"Peso dell'arco:\"\n"
"	Romanian = \"Cost Muchie:\"\n"
"	Spanish = \"Peso de la arista:\"\n"
"	SwedishChef = \"Idge-a veeeght:\"\n"
"};\n"
"\"Edge flow:\" = {\n"
"	Catalan = \"Flux d'aresta:\"\n"
"	ChineseSimp = \"流：\"\n"
"	French = \"Flux de l'arête :\"\n"
"	Italian = \"Flusso dell'arco:\"\n"
" 	Romanian = \"Flux muchie:\"\n"
"	Spanish = \"Flujo de arista:\"\n"
"	SwedishChef = \"Idge-a floo:\"\n"
"};\n"
"\"Vertex Properties\" = {\n"
"	Catalan = \"Propietats del vértex\"\n"
"	ChineseSimp = \"顶点属性\"\n"
"	French = \"Propriétés du sommet\"\n"
"	German = \"Vertex Eigenschaften\"\n"
"	Italian = \"Proprietà del vertice\"\n"
" 	Romanian = \"Proprietãþi Vârf\"\n"
"	Spanish = \"Propiedades del vértice\"\n"
"	SwedishChef = \"Fertex Pruperteees\"\n"
"};\n"
"\"Label:\" = {\n"
"	Catalan = \"Etiqueta:\"\n"
"	ChineseSimp = \"标签：\"\n"
"	French = \"Étiquette :\"\n"
"	German = \"Bezeichnung:\"\n"
"	Italian = \"Etichetta:\"\n"
"	Romanian = \"Etichetã:\"\n"
"	Spanish = \"Etiqueta:\"\n"
"	SwedishChef = \"Lebel:\"\n"
"};\n"
"\n"
"\"Load File\" = {\n"
"	Catalan = \"Obrir Fitxer\"\n"
"	ChineseSimp = \"打开文件\"\n"
"	French = \"Ouvrir un fichier\"\n"
"	German = \"Datei öffnen\"\n"
"	Italian = \"Apri File\"\n"
"	Romanian = \"Încarcã Fiºier\"\n"
"	Spanish = \"Abrir Fichero\"\n"
"	SwedishChef = \"Lued Feele-a\"\n"
"};\n"
"\"Save File\" = {\n"
"	Catalan = \"Desar Fitxer\"\n"
"	ChineseSimp = \"保存文件\"\n"
"	French = \"Sauver le fichier\"\n"
"	German = \"Datei Speichern\"\n"
"	Italian = \"Salva File\"\n"
"	Romanian = \"Salveazã Fiºier\"\n"
"	Spanish = \"Guardar Fichero\"\n"
"	SwedishChef = \"Sefe-a Feele-a\"\n"
"};\n"
"\"Print to File\" = {\n"
"	Catalan = \"Imprimir a Fitxer\"\n"
"	ChineseSimp = \"打印到文件\"\n"
"	French = \"Imprimer dans un fichier\"\n"
"	German = \"in Datei Drucken\"\n"
"	Italian = \"Stampa su File\"\n"
"	Romanian = \"Tipãreste în Fiºier\"\n"
"	Spanish = \"Imprimir a Fichero\"\n"
"	SwedishChef = \"Preent tu Feele-a\"\n"
"};\n"
"\n"
"\"Exponent:\" = {\n"
"	Catalan = \"Exponent:\"\n"
"	ChineseSimp = \"指数：\"\n"
"	French = \"Exposant :\"\n"
"	German = \"Exponent:\"\n"
"	Italian = \"Esponente:\"\n"
"	Romanian = \"Exponent:\"\n"
"	Spanish = \"Exponente:\"\n"
"	SwedishChef = \"Ixpunent:\"\n"
"};\n"
"\n"
"\"Subgraph\" = \"S&ubgraph\" subst \"&\" / \"\";\n"
"\"Shortest Path\" = \"&Shortest Path\" subst \"&\" / \"\";\n"
"\"Breadth-First Search\" = \"&Breadth-First Search\" subst \"&\" / \"\";\n"
"\"Depth-First Search\" = \"&Depth-First Search\" subst \"&\" / \"\";\n"
"\"Maximum Flow\" = \"Maximum &Flow\" subst \"&\" / \"\";\n"
"\"Connectivity\" = \"&Connectivity\" subst \"&\" / \"\";\n"
"\"Eulericity\" = \"&Eulericity\" subst \"&\" / \"\";\n"
"\"Adjacency Matrix\" = \"&Adjacency Matrix\" subst \"&\" / \"\";\n"
"\"Degree Sequence\" = \"&Degree Sequence\" subst \"&\" / \"\";\n"
"\"Diameter\" = \"D&iameter\" subst \"&\" / \"\";\n"
"\"Radius\" = \"&Radius\" subst \"&\" / \"\";\n"
"\"Chromatic Number\" = \"&Chromatic Number\" subst \"&\" / \"\";\n"
"\"Chromatic Index\" = \"C&hromatic Index\" subst \"&\" / \"\";\n"
"\"Chromatic Polynomial\" = \"Chromatic &Polynomial\" subst \"&\" / \"\";\n"
"\n"
"\"Prefab Parameter\" = {\n"
"	Catalan = \"Paràmetre de Preestablert\"\n"
"	ChineseSimp = \"预置图参数\"\n"
"	French = \"Paramètre\"\n"
"	German = \"Ausgangsparameter\"\n"
"	Italian = \"Parametro Prestabilito\"\n"
"	Romanian = \"Parametru Prestabilit\"\n"
"	Spanish = \"Parámetro de Preestablecido\"\n"
"	SwedishChef = \"Preffeb Peremeter\"\n"
"};\n"
"\"Complete:\" = \"Complete (&Kn)\" subst \" (&Kn)\" / \":\";\n"
"\"Complete &Bipartite:\" = \"Complete &Bipartite (Kn,m)\" subst \" (Kn,m)\" / \":\";\n"
"\"Complete Bipartite:\" = \"Complete &Bipartite:\" subst \"&\" / \"\";\n"
"\"Cycle:\" = \"Cycle (&Cn)\" subst \" (&Cn)\" / \":\";\n"
"\"Gear:\" = \"Gear (&Gn)\" subst \" (&Gn)\" / \":\";\n"
"\"Ladder:\" = \"Ladder (&Ln)\" subst \" (&Ln)\" / \":\";\n"
"\"Lattice:\" = \"Lattice (Ln,m)\" subst \" (Ln,m)\" / \":\";\n"
"\"Null:\" = \"Null (&Nn)\" subst \" (&Nn)\" / \":\";\n"
"\"Star:\" = \"Star (&Sn)\" subst \" (&Sn)\" / \":\";\n"
"\"Wheel:\" = \"Wheel (&Wn)\" subst \" (&Wn)\" / \":\";\n"
"\n"
"#------------------------- Result messages -------------------------#\n"
"\n"
"# This is used, for example, when there is no result\n"
"# (e.g. the degree sequence of an empty graph)\n"
"\"(none)\" = \"(\" + \"none\" + \")\";\n"
"\"none\" = {\n"
"	Catalan = \"cap\"\n"
"	ChineseSimp = \"无\"\n"
"	French = \"aucun\"\n"
"	German = \"keine\"\n"
"	Italian = \"niente\"\n"
"	Romanian = \"none\"\n"
"	Spanish = \"nada\"\n"
"	SwedishChef = \"nune-a\"\n"
"};\n"
"\n"
"\"Graph is connected.\" = {\n"
"	Catalan = \"Graf connex.\"\n"
"	ChineseSimp = \"这是一个连通图。\"\n"
"	French = \"Le graphe est connexe.\"\n"
"	German = \"Der Graph ist zusammenhängend.\"\n"
"	Italian = \"Grafo connesso.\"\n"
"	Romanian = \"Graful este conex.\"\n"
"	Spanish = \"Grafo conexo.\"\n"
"	SwedishChef = \"Greph is cunnected.\"\n"
"};\n"
"\"Graph is weakly connected.\" = {\n"
"	Catalan = \"El graf té connexió feble.\"\n"
"	ChineseSimp = \"这是一个弱连通图。\"\n"
"	French = \"Le graphe est faiblement connexe.\"\n"
"	German = \"Der Graph ist schwach zusammehängend.\"\n"
"	Italian = \"Grafo è debolmente connesso.\"\n"
"	Romanian = \"Graful nu este tare conex.\"\n"
"	Spanish = \"El grafo tiene conexión débil.\"\n"
"	SwedishChef = \"Greph is veekly cunnected.\"\n"
"};\n"
"\"Graph is strongly connected.\" = {\n"
"	Catalan = \"El digraf és fortament connex.\"\n"
"	ChineseSimp = \"这是一个强连通图。\"\n"
"	French = \"Le graphe est fortement connexe.\"\n"
"	German = \"Der Graph ist stark zusammenhängend.\"\n"
"	Italian = \"Grafo è fortemente connesso.\"\n"
"	Romanian = \"Graful este tare conex.\"\n"
"	Spanish = \"El digrafo es fuertemente conexo.\"\n"
"	SwedishChef = \"Greph is strungly cunnected.\"\n"
"};\n"
"\"Graph is Eulerian.\" = {\n"
"	Catalan = \"Graf eulerià.\"\n"
"	ChineseSimp = \"这是一个欧拉图。\"\n"
"	French = \"Le graphe est eulérien.\"\n"
"	German = \"Der Graph ist ein Eulerscher Graph.\"\n"
"	Italian = \"Grafo Euleriano.\"\n"
"	Romanian = \"Graful este eulerian.\"\n"
"	Spanish = \"Grafo euleriano.\"\n"
"	SwedishChef = \"Greph is Ioolereeun.\"\n"
"};\n"
"\"Graph is neither Eulerian nor Semi-Eulerian.\" = {\n"
"	Catalan = \"Graf ni eulerià ni semi eulerià.\"\n"
"	ChineseSimp = \"这是既不是欧拉图，也不是准欧拉图。\"\n"
"	French = \"Le graphe n'est ni eulérien ni semi-eulérien.\"\n"
"	German = \"Der Graph ist weder ein eulerscher Graph noch ein \"\n"
"							\"semi-eulerscher.\"\n"
"	Italian = \"Grafo ne euleriano ne semi euleriano.\"\n"
"	Romanian = \"Graful nu este nici eulerian nici semi-eulerian.\"\n"
"	Spanish = \"Grafo ni euleriano ni semi euleriano.\"\n"
"	SwedishChef = \"Greph is neeezeer Ioolereeun nur Semee-Ioolereeun.\"\n"
"};\n"
"\"Graph is not connected.\" = {\n"
"	Catalan = \"Graf no connex.\"\n"
"	ChineseSimp = \"这不是一个连通图。\"\n"
"	French = \"Le graphe n'est pas connexe.\"\n"
"	German = \"Der Graph ist nicht zusammenhängend.\"\n"
"	Italian = \"Grafo non connesso.\"\n"
"	Romanian = \"Graful nu este conex.\"\n"
"	Spanish = \"Grafo no conexo.\"\n"
"	SwedishChef = \"Greph is nut cunnected.\"\n"
"};\n"
"\"Graph is Semi-Eulerian.\" = {\n"
"	Catalan = \"Graf semi eulerià.\"\n"
"	ChineseSimp = \"这是一个准欧拉图。\"\n"
"	French = \"Le graphe est semi-eulérien.\"\n"
"	German = \"Der Graph ist ein semi-eulerscher Graph.\"\n"
"	Italian = \"Grafo semi Euleriano.\"\n"
"	Romanian = \"Graful este semi-eulerian.\"\n"
"	Spanish = \"Grafo semi euleriano.\"\n"
"	SwedishChef = \"Greph is Semee-Ioolereeun.\"\n"
"};\n"
"\"No path found.\" = {\n"
"	Catalan = \"Cap camí trobat.\"\n"
"	ChineseSimp = \"未找到路径。\"\n"
"	French = \"Aucun chemin trouvé.\"\n"
"	German = \"Kein Weg gefunden.\"\n"
"	Italian = \"Percorso non trovato.\"\n"
"	Romanian = \"Nici un drum gasit.\"\n"
"	Spanish = \"No se ha encontrado camino.\"\n"
"	SwedishChef = \"Nu pet fuoond.\"\n"
"};\n"
"\"Shortest path is %i.\" = {\n"
"	Catalan = \"El camí més curt és %i.\"\n"
"	ChineseSimp = \"最短路是 %i。\"\n"
"	French = \"Le plus court chemin est %i.\"\n"
"	German = \"Der Kürzeste Weg ist %i.\"\n"
"	Italian = \"Il cammino minimo é %i.\"\n"
"	Romanian = \"Cel mai scurt drum este %i.\"\n"
"	Spanish = \"El camino más corto es %i.\"\n"
"	SwedishChef = \"Shurtest pet is %i.\"\n"
"};\n"
"\"Maximum flow is %i.\" = {\n"
"	ChineseSimp = \"最大流是 %i。\"\n"
"	SwedishChef = \"Mexeemoom floo is %i.\"\n"
"};\n"
"\n"
"\n"
"#------------------------- Undo messages -------------------------#\n"
"\n"
"\"Load graph\" = {\n"
"	Catalan = \"Carrega graf\"\n"
"	ChineseSimp = \"打开文件\"\n"
"	French = \"Charger un graphe\"\n"
"	Italian = \"Carica grafo\"\n"
" 	Romanian = \"Încarcã graf\"	\n"
"	Spanish = \"Carga grafo\"\n"
"	SwedishChef = \"Lued greph\"\n"
"};\n"
"\"Clear graph\" = {\n"
"	Catalan = \"Esborrar graf\"\n"
"	ChineseSimp = \"清空图\"\n"
"	French = \"Effacer le graphe\"\n"
"	German = \"Lösche graph\"\n"
"	Italian = \"Cancella grafo\"\n"
" 	Romanian = \"ªterge graful\"\n"
"	Spanish = \"Borrar grafo\"\n"
" 	SwedishChef = \"Cleer greph\"\n"
"};\n"
"\"Complement graph\" = {\n"
"	Catalan = \"Fer complementari\"\n"
"	ChineseSimp = \"补图\"\n"
"	French = \"Graphe complémentaire\"\n"
"	German = \"Komplementärgraph\"\n"
"	Italian = \"Grafo completo\"\n"
"	Romanian = \"Complementul grafului\"\n"
"	Spanish = \"Hacer complementario\"\n"
"	SwedishChef = \"Cumplemunt greph\"\n"
"};\n"
"\"Line Graph\" = \"&Line Graph\" subst \"&\" / \"\";\n"
"\"Induced subgraph\" = {\n"
"	Catalan = \"Subgraf Induït\"\n"
"	ChineseSimp = \"诱导子图\"\n"
"	French = \"Graphe induit\"\n"
"	Italian = \"Incluso sottografo\"\n"
"	Romanian = \"Subgraful indus\"\n"
"	Spanish = \"Subgrafo inducido\"\n"
"	SwedishChef = \"Indooced soobgreph\"\n"
"};\n"
"\"Make prefab\" = {\n"
"	Catalan = \"Fer predefinit\"\n"
"	ChineseSimp = \"使用预制图\"\n"
"	French = \"Créer un préconçu\"\n"
"	German = \"Erzeuge prefab\"\n"
"	Italian = \"Crea predefinito\"\n"
"	Romanian = \"Creazã predefinit\"\n"
"	Spanish = \"Hacer predefinido\"\n"
"	SwedishChef = \"Meke-a preffeb\"\n"
"};\n"
"\n"
"\"Add vertex\" = {\n"
"	Catalan = \"Afegir vèrtex\"\n"
"	ChineseSimp = \"增加顶点\"\n"
"	French = \"Ajouter un vecteur\"\n"
"	German = \"Vertex hinzufügen\"\n"
"	Italian = \"Aggiungi vertice\"\n"
"	Romanian = \"Adaugã vârf\"\n"
"	Spanish = \"Añadir vértice\"\n"
"	SwedishChef = \"Edd fertex\"\n"
"};\n"
"\"Add edge\" = {\n"
"	Catalan = \"Afegir aresta\"\n"
"	ChineseSimp = \"增加边\"\n"
"	French = \"Ajouter une arête\"\n"
"	German = \"Kante hinzufügen\"\n"
"	Italian = \"Aggiungi vertice\"\n"
"	Romanian = \"Adaugã muchie\"\n"
"	Spanish = \"Añadir arista\"\n"
"	SwedishChef = \"Edd idge-a\"\n"
"};\n"
"\"Delete objects\" = {\n"
"	Catalan = \"Esborra objectes\"\n"
"	ChineseSimp = \"删除对象\"\n"
"	French = \"Supprimer les objets\"\n"
"	German = \"Lösche objekt\"\n"
"	Italian = \"Cancella oggetti\"\n"
"	Romanian = \"ªterge obiecte\"\n"
"	Spanish = \"Borra objetos\"\n"
"	SwedishChef = \"Delete-a oobjects\"\n"
"};\n"
"\n"
"\"Rename vertex\" = {\n"
"	Catalan = \"Reanomenar vèrtex\"\n"
"	ChineseSimp = \"重命名顶点\"\n"
"	French = \"Renommer le sommet\"\n"
"	German = \"Vertex umbenennen\"\n"
"	Italian = \"Rinomina vertice\"\n"
"	Romanian = \"Redenumeºte vârful\"\n"
"	Spanish = \"Renombrar vértice\"\n"
"	SwedishChef = \"Runeme-a fertex\"\n"
"};\n"
"\"Edge direction:\" = {\n"
"	Catalan = \"Direcció d'aresta:\"\n"
"	ChineseSimp = \"边的方向：\"\n"
"	French = \"Direction de l'arc:\"\n"
"	German = \"Kantenrichtung:\"\n"
"	Italian = \"Direzione arco:\"\n"
"	Romanian = \"Direcþia arcului:\"\n"
"	Spanish = \"Dirección de arista:\"\n"
"	SwedishChef = \"Idge-a deerecshun:\"\n"
"};\n"
"\"Change edge weight\" = {\n"
"	Catalan = \"Canviar pes d'aresta\"\n"
"	ChineseSimp = \"改变边的权值\"\n"
"	French = \"Changer le poids de l'arête\"\n"
"	German = \"Ändere Kantengewicht\"\n"
"	Italian = \"Cambia peso dell'arco\"\n"
"	Romanian = \"Modificã costul muchiei\"\n"
"	Spanish = \"Cambiar peso de arista\"\n"
"	SwedishChef = \"Chunge-a idge-a veeeght\"\n"
"};\n"
"\"Change edge direction\" = {\n"
"	Catalan = \"Canviar direcció d'aresta\"\n"
"	ChineseSimp = \"改变边的方向\"\n"
"	French = \"Changer la direction de l'arc\"\n"
"	German = \"Ändere Kantenrichtung\"\n"
"	Italian = \"Cambia direzione arco\"\n"
"	Romanian = \"Modificã direcþia arcului\"\n"
"	Spanish = \"Cambiar dirección de arista\"\n"
"	SwedishChef = \"Chunge-a idge-a deerecshun\"\n"
"};\n"
"\"Change edge weight and direction\" = {\n"
"	Catalan = \"Canviar pes i direcció d'aresta\"\n"
"	ChineseSimp = \"改变边的权值和方向\"\n"
"	French = \"Changer le poids et la direction de l'arc\"\n"
"	German = \"Ändere Kantengewicht und -richtung\"\n"
"	Italian = \"Cambia peso e direzione arco\"\n"
"	Romanian = \"Modificã costul ºi direcþia arcului\"\n"
"	Spanish = \"Cambiar peso y dirección de arista\"\n"
"	SwedishChef = \"Chunge-a idge-a veeeght und deerecshun\"\n"
"};\n"
"\n"
"#------------------------- Error messages -------------------------#\n"
"\n"
"\"At least one vertex must be selected to induce a subgraph.\" = {\n"
"	Catalan = \"Per induir un subgraf, cal haver seleccionat un o més \"\n"
"								\"vèrtexs.\"\n"
"	ChineseSimp = \"至少要选中一个顶点才可以作诱导子图。\"\n"
"	French = \"Pour induire un sous-graphe, vous devez sélectionner au\"\n"
"	                                                \"moins un sommet.\"\n"
"	German = \"Mindestens ein vertex muss ausgewählt sein um den Subgraph \"\n"
"								\"zu bewegen.\"\n"
"	Italian = \"Per indurre un sottografo, di deve selezionare un vertice.\"\n"
"	Romanian = \"Cel puþin un vârf trebuie selectat pentru a induce un subgraf.\"\n"
"	Spanish = \"Para inducir un subgrafo, debe seleccionarse, como mínimo, \"\n"
"								\"un vértice.\"\n"
"	SwedishChef = \"Et leest oone-a fertex moost be-a selected tu \"\n"
"						\"indooce-a a soobgreph.\"\n"
"};\n"
"\"Exactly one vertex must be selected to perform a Breadth-First Search.\" = {\n"
"	Catalan = \"Per tal de fer una cerca per amplada cal sel·leccionar \"\n"
"							\"un sol vértex.\"\n"
"	ChineseSimp = \"必须选中一个顶点才可以进行宽度优先搜索。\"\n"
"	French = \"Pour effectuer une recherche en largeur d'abord, un\"\n"
"				\"sommet exactement doit être sélectionné.\"\n"
"	German = \"Für die Breitensuche muss genau ein Knoten ausgewählt sein.\"\n"
"	Italian = \"Per effettuare una ricerca in ampiezza, si deve selezionare\"\n"
"	                                                \" un solo vertice.\"\n"
"	Romanian = \"Exact un vârf trebuie selectat pentru a cãuta \"\n"
"							\"în lãþime.\"\n"
"	Spanish = \"Para efectuar una búsqueda por anchura hay que seleccionar \"\n"
"							\"un sólo vértice.\"\n"
"	SwedishChef = \"Ixectly oone-a fertex moost be-a selected tu perffurm \"\n"
"							\"a Breedt-Furst Seerch.\"\n"
"};\n"
"\"Exactly one vertex must be selected to perform a Depth-First Search.\" = {\n"
"	Catalan = \"Per tal de fer una cerca en profunditat cal \"\n"
"						\"sel·leccionar un sol vértex.\"\n"
"	ChineseSimp = \"必须选中一个顶点才可以进行深度优先搜索。\"\n"
"	French = \"Pour effectuer une recherche en profondeur d'abord, un\"\n"
"				\"sommet exactement doit être sélectionné.\"\n"
"	German = \"Für die Tiefensuche muss genau ein Knoten ausgewählt sein.\"\n"
"	Italian = \"Per effettuare una ricerca in profondità, si deve \"\n"
"						\"selezionare un solo vertice.\"\n"
"	Romanian = \"Exact un vârf trebuie selectat pentru a cãuta \"\n"
"							\"în adâncime.\"\n"
"	Spanish = \"Para efectuar una búsqueda en profundidad hay que \"\n"
"						\"seleccionar un sólo vértice.\"\n"
"	SwedishChef = \"Ixectly oone-a fertex moost be-a selected tu perffurm \"\n"
"							\"a Dept-Furst Seerch.\"\n"
"};\n"
"\"Exactly two vertices must be selected to find a shortest path.\" = {\n"
"	Catalan = \"Per tal de cercar el camí més curt, cal que hi hagi \"\n"
"						\"dos vértexs sel·leccionats.\"\n"
"	ChineseSimp = \"必须选中两个顶点才可以寻找最短路。\"\n"
"	French = \"Pour effectuer une recherche du plus court chemin,\"\n"
"			\"deux sommets exactement doivent être sélectionnés.\"\n"
"	German = \"Um den kürzesten Weg zu finden, müssen genau zwei \"\n"
"						\"Punkte ausgewählt sein.\"\n"
"	Italian = \"Per trovare un cammino minimo, si devono selezionare\"\n"
"		                                         \" due vertici.\"\n"
"	Romanian = \"Exact douã vârfuri trebuie selectate pentru a cãuta cel \"\n"
"						\"mai scurt drum.\"\n"
"	Spanish = \"Para buscar el camino más corto debe haber exactamante \"\n"
"						\"dos vértices seleccionados.\"\n"
"	SwedishChef = \"Ixectly tvu ferteeces moost be-a selected tu feend a \"\n"
"							\"shurtest pet.\"\n"
"};\n"
"\"Exactly two vertices must be selected to find a maximum flow.\" = {\n"
"	Catalan = \"Cal seleccionar exactament dos vèrtexs per trobar-ne\"\n"
"							\" el flux màxim.\"\n"
"	ChineseSimp = \"必须选中两个顶点才可以寻找最大流。\"\n"
"	French = \"Pour trouver un flux maximal, deux sommets exactement\"\n"
"					\"doivent être sélectionnés.\"\n"
"	Italian = \"Per trovare un flusso massimo, si devono selezionare\"\n"
"		                                         \" due vertici.\"\n"
" 	Romanian = \"Exact douã vârfuri trebuie selectate pentru a cãuta\"\n"
" 							\"fluxul maxim.\"\n"
"	Spanish = \"Hay que seleccionar exactamente dos vértices para encontrar\"\n"
"							\" el flujo máximo.\"\n"
"	SwedishChef = \"Ixectly tvu ferteeces moost be-a selected tu feend a \"\n"
"							\"mexeemoom floo.\"\n"
"};\n"
"\n"
"#------------------------- Miscellaneous -------------------------#\n"
"\n"
"# Stuff appearing in the statusbar (bottom of main area)\n"
"\"About GraphThing\" = {\n"
"	Catalan = \"Sobre de GraphThing\"\n"
"	ChineseSimp = \"关于 GraphThing\"\n"
"	French = \"À propos de GraphThing\"\n"
"	German = \"Über GraphThing\"\n"
"	Italian = \"Circa GraphThing\"\n"
"	Romanian = \"Despre GraphThing\"\n"
"	Spanish = \"Acerca de GraphThing\"\n"
"	SwedishChef = \"Ebuoot GrephTheeng\"\n"
"};\n"
"\"Computing chromatic number...\" = {\n"
"	Catalan = \"Calculant número cromàtic...\"\n"
"	ChineseSimp = \"计算色数...\"\n"
"	French = \"Calcul du nombre chromatique...\"\n"
"	German = \"Berechne chromatische Zahl...\"\n"
"	Italian = \"Calcolando il numero cromatico...\"\n"
"	Romanian = \"Calculez numãrul cromatic...\"\n"
"	Spanish = \"Calculando número cromático...\"\n"
"	SwedishChef = \"Cumpooteeng chrumeteec noomber...\"\n"
"};\n"
"\"Computing chromatic index...\" = {\n"
"	Catalan = \"Calculant l'índex cromàtic...\"\n"
"	ChineseSimp = \"计算色指数...\"\n"
"	French = \"Calcul de l'index chromatique...\"\n"
"	German = \"Berechnung des chromatischen index...\"\n"
"	Italian = \"Calcolando l'indice cromatico...\"\n"
"	Romanian = \"Calculez index-ul cromatic...\"\n"
"	Spanish = \"Calculando el índice cromático...\"\n"
"	SwedishChef = \"Cumpooteeng chrumeteec index...\"\n"
"};\n"
"\"Computing chromatic polynomial...\" = {\n"
"	Catalan = \"Calculant polinomi cromàtic...\"\n"
"	ChineseSimp = \"计算色多项式...\"\n"
"	French = \"Calcul du polynome chromatique...\"\n"
"	German = \"Berechne chromatisches Polynom...\"\n"
"	Italian = \"Calcolando il polinomio cromatico...\"\n"
"	Romanian = \"Calculez polinomul cromatic...\"\n"
"	Spanish = \"Calculando polinomio cromático...\"\n"
"	SwedishChef = \"Cumpooteeng chrumeteec pulynumeeel...\"\n"
"};\n"
"\"Determining diameter...\" = {\n"
"	Catalan = \"Calculando diàmetre...\"\n"
"	ChineseSimp = \"求出直径...\"\n"
"	French = \"Calcul du diamètre...\"\n"
"	German = \"Bestimme Durchmesser...\"\n"
"	Italian = \"Calcolando diametro...\"\n"
"	Romanian = \"Calculez diametrul...\"\n"
"	Spanish = \"Calculando diámetro...\"\n"
"	SwedishChef = \"Determeening deeemeter...\"\n"
"};\n"
"\"Determining Eulericity...\" = {\n"
"	Catalan = \"Comprobant eulericitat...\"\n"
"	ChineseSimp = \"确定是否为欧拉图...\"\n"
"	French = \"Vérification de l'eulericité...\"\n"
"	German = \"Überprüfe, ob eulersch...\"\n"
"	Italian = \"Determinando l'Eulericità...\"\n"
"	Romanian = \"Determin Eulericitatea...\"\n"
"	Spanish = \"Comprobando eulericidad...\"\n"
"	SwedishChef = \"Determeening Ioolereecity...\"\n"
"};\n"
"\"Determining radius...\" = {\n"
"	Catalan = \"Calculant radi...\"\n"
"	ChineseSimp = \"求出半径...\"\n"
"	French = \"Calcul du rayon...\"\n"
"	German = \"Bestimme Radius...\"\n"
"	Italian = \"Determinando il raggio...\"\n"
"	Romanian = \"Determin raza...\"\n"
"	Spanish = \"Calculando radio...\"\n"
"	SwedishChef = \"Determeening redeeoos...\"\n"
"};\n"
"\"Finding shortest path...\" = {\n"
"	Catalan = \"Cercant camí més curt...\"\n"
"	ChineseSimp = \"找出最短路...\"\n"
"	French = \"Recherche du plus court chemin...\"\n"
"	German = \"Suche Kürzesten Weg...\"\n"
"	Italian = \"Cercando il cammino minimo...\"\n"
"	Romanian = \"Caut cel mai scurt drum...\"\n"
"	Spanish = \"Buscando camino más corto...\"\n"
"	SwedishChef = \"Feending shurtest pet...\"\n"
"};\n"
"\"Performing BFS...\" = {\n"
"	Catalan = \"Cercant per amplada...\"\n"
"	ChineseSimp = \"进行宽度优先搜索...\"\n"
"	French = \"En cours : recherche en largeur d'abord...\"\n"
"	German = \"Durchsuche mit BFS...\"\n"
"	Italian = \"Ricerca in ampiezza...\"\n"
"	Romanian = \"Caut în lãþime...\"\n"
"	Spanish = \"Buscando por anchura...\"\n"
"	SwedishChef = \"Perffurmeeng BFS...\"\n"
"};\n"
"\"Performing DFS...\" = {\n"
"	Catalan = \"Cercant en profunditat...\"\n"
"	ChineseSimp = \"进行深度优先搜索...\"\n"
"	French = \"En cours : recherche en profondeur d'abord...\"\n"
"	German = \"Durchsuche mit DFS...\"\n"
"	Italian = \"Ricerca in Profondità...\"\n"
"	Romanian = \"Caut în adâncime...\"\n"
"	Spanish = \"Buscando en profundidad...\"\n"
"	SwedishChef = \"Perffurmeeng DFS...\"\n"
"};\n"
"\"Finding Minimum Spanning Tree...\" = {\n"
"	Catalan = \"Cercant arbre d'expansió mínim...\"\n"
"	ChineseSimp = \"寻找最小生成树...\"\n"
"	French = \"Recheche de l'enjambement d'arbre minimal...\"\n"
"	German = \"Suche minimalen spannenden Baum...\"\n"
"	Italian = \"Trova albero dei cammini minimo...\"\n"
"	Romanian = \"Caut arborele minim de acoperire...\"\n"
"	Spanish = \"Buscando árbol de expansión mínimo...\"\n"
"	SwedishChef = \"Feending Meenimoom Spunneeng Tree-a...\"\n"
"};\n"
"\"Finding Maximum Flow...\" = {\n"
"	Catalan = \"Cercant flux màxim...\"\n"
"	ChineseSimp = \"寻找最大流...\"\n"
"	French = \"Calcul du flux maximal...\"\n"
"	Italian = \"Trova il Massimo Flusso...\"\n"
" 	Romanian = \"Caut fluxul maxim...\"\n"
"	Spanish = \"Buscando flujo máximo...\"\n"
"	SwedishChef = \"Feending Mexeemoom Floo...\"\n"
"};\n"
"\"Prefab\" = \"&Prefab\" subst \"&\" / \"\";\n"
"\"Prefab...\" = \"Prefab\" + \"...\";\n"
"\"Ready\" = {\n"
"	Catalan = \"Fet\"\n"
"	ChineseSimp = \"准备好了\"\n"
"	French = \"Prêt\"\n"
"	German = \"Fertig\"\n"
"	Italian = \"Pronto\"\n"
"	Romanian = \"Gata\"\n"
"	Spanish = \"Listo\"\n"
"	SwedishChef = \"Reedy\"\n"
"};\n"
"\"Ready.\" = \"Ready\" + \".\";\n"
"\"(Vertex Mode)\" = \"(\" + \"Vertex Mode\" + \")\";\n"
"\"Vertex Mode\" = {\n"
"	Catalan = \"Mode Vèrtex\"\n"
"	ChineseSimp = \"顶点模式\"\n"
"	French = \"Mode sommet\"\n"
"	German = \"Vertex Modus\"\n"
"	Italian = \"Modalità Vertice\"\n"
"	Romanian = \"Mod Vârf\"\n"
"	Spanish = \"Modo Vértice\"\n"
"	SwedishChef = \"Fertex Mude-a\"\n"
"};\n"
"\"(Edge Mode)\" = \"(\" + \"Edge Mode\" + \")\";\n"
"\"Edge Mode\" = {\n"
"	Catalan = \"Mode Aresta\"\n"
"	ChineseSimp = \"边模式\"\n"
"	French = \"Mode arête\"\n"
"	German = \"Kanten Modus\"\n"
"	Italian = \"Modalità Arco\"\n"
"	Romanian = \"Mod Muchie\"\n"
"	Spanish = \"Modo Arista\"\n"
"	SwedishChef = \"Idge-a Mude-a\"\n"
"};\n"
"\"Ready \" = \"Ready\" + \" \";\n"
"\"Ready (Vertex Mode).\" = \"Ready \" + \"(Vertex Mode)\" + \".\";\n"
"\"Ready (Edge Mode).\" = \"Ready \" + \"(Edge Mode)\" + \".\";\n"
"\n"
"\"Change to Vertex Mode\" = {\n"
"	Catalan = \"Canviar a mode vèrtex\"\n"
"	ChineseSimp = \"转换到顶点模式\"\n"
"	French = \"Changer pour le mode sommet\"\n"
"	German = \"Wechsele in den Knoten Modus\"\n"
"	Italian = \"Cambia a Modalità Vertice\"\n"
"	Romanian = \"Schimbã în Mod Vârf\"\n"
"	Spanish = \"Cambiar a modo vértice\"\n"
"	SwedishChef = \"Chunge-a tu Fertex Mude-a\"\n"
"};\n"
"\"Change to Edge Mode\" = {\n"
"	Catalan = \"Canviar a mode aresta\"\n"
"	ChineseSimp = \"转换到边模式\"\n"
"	French = \"Changer pour le mode arête\"\n"
"	German = \"Wechsele in den Vertex Modus\"\n"
"	Italian = \"Cambia a Modalità Arco\"\n"
"	Romanian = \"Schimbã în Mod Muchie\"\n"
"	Spanish = \"Cambiar a modo arista\"\n"
"	SwedishChef = \"Chunge-a tu Idge-a Mude-a\"\n"
"};\n"
"\n"
"\"Testing connectivity...\" = {\n"
"	Catalan = \"Comprovant si és connex...\"\n"
"	ChineseSimp = \"测试连通性...\"\n"
"	French = \"Test de connexité...\"\n"
"	German = \"Überprüfe Verbindung...\"\n"
"	Italian = \"Provando la convessità...\"\n"
"	Romanian = \"Testez conectivitatea...\"\n"
"	Spanish = \"Comprobando si es conexo...\"\n"
"	SwedishChef = \"Testeeng cunnecteefity...\"\n"
"};\n"
"\n"
"#------------------------- Literals -------------------------#\n"
"\n"
"\".\" = literal;\n"
"\"...\" = literal;\n"
"\" \" = literal;\n"
"\" (\" = literal;\n"
"\"(\" = literal;\n"
"\")\" = literal;\n"
;

// The End.
