/* src/config.h.  Generated from config.h.in by configure.  */
//
//	config.h
//

#ifndef __CONFIG_H__
#define __CONFIG_H__

// GraphThing version information
#define GT_VERSION "1.3.2"

// was --with-dev passed to configure script?
#define GT_WITH_DEV 1

// NLS stuff
#define ENABLE_NLS 1
#define LANG_DIALOG_IS_DISABLED 1

// System type
/* #undef USING_LINUX */
/* #undef USING_FREEBSD */
#define USING_OSX 1

#endif	// __CONFIG_H__
